dovecot-2.2: lib-http: server: Fixed handling of disconnection w...

dovecot at dovecot.org dovecot at dovecot.org
Wed Sep 10 10:43:58 UTC 2014


details:   http://hg.dovecot.org/dovecot-2.2/rev/992f17769cca
changeset: 17766:992f17769cca
user:      Stephan Bosch <stephan at rename-it.nl>
date:      Wed Sep 10 13:39:36 2014 +0300
description:
lib-http: server: Fixed handling of disconnection while request is being handled.
This would cause an assert failure.

diffstat:

 src/lib-http/http-server-connection.c |  4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diffs (14 lines):

diff -r 8b5664bce4a0 -r 992f17769cca src/lib-http/http-server-connection.c
--- a/src/lib-http/http-server-connection.c	Tue Sep 09 17:09:30 2014 +0300
+++ b/src/lib-http/http-server-connection.c	Wed Sep 10 13:39:36 2014 +0300
@@ -303,8 +303,8 @@
 	http_server_connection_ref(conn);
 	http_server_connection_request_callback(conn, req);
 	http_server_connection_unref(&conn);
-	if (conn == NULL) {
-		/* the callback managed to get this connection destroyed */
+	if (conn == NULL || conn->closed) {
+		/* the callback managed to get this connection destroyed/closed */
 		return FALSE;
 	}
 


More information about the dovecot-cvs mailing list